@@ -10,7 +10,9 @@ import (
 	"path"
 	"path/filepath"
 	"reflect"
+	"regexp"
 	"strconv"
+	"strings"
 	"sync"
 	"time"
 
@@ -39,7 +41,8 @@ const (
 	// APISecondsPerPoll how frequently to poll for new Events or Status in WaitFor functions
 	APISecondsPerPoll = 3
 	// Maximum wait time for retries
-	APIRetryMaxWaitTime = time.Duration(30) * time.Second
+	APIRetryMaxWaitTime       = time.Duration(30) * time.Second
+	APIDefaultCacheExpiration = time.Minute * 15
 )
 
 var envDebug = false
@@ -82,12 +85,13 @@ type clientCacheEntry struct {
 }
 
 type (
-	Request = resty.Request
-	Logger  = resty.Logger
+	Request  = resty.Request
+	Response = resty.Response
+	Logger   = resty.Logger
 )
 
 func init() {
-	// Wether or not we will enable Resty debugging output
+	// Whether we will enable Resty debugging output
 	if apiDebug, ok := os.LookupEnv("LINODE_DEBUG"); ok {
 		if parsed, err := strconv.ParseBool(apiDebug); err == nil {
 			envDebug = parsed
@@ -133,11 +137,49 @@ func (c *Client) SetLogger(logger Logger) *Client {
 
 // OnBeforeRequest adds a handler to the request body to run before the request is sent
 func (c *Client) OnBeforeRequest(m func(request *Request) error) {
-	c.resty.OnBeforeRequest(func(client *resty.Client, req *resty.Request) error {
+	c.resty.OnBeforeRequest(func(_ *resty.Client, req *resty.Request) error {
 		return m(req)
 	})
 }
 
+// OnAfterResponse adds a handler to the request body to run before the request is sent
+func (c *Client) OnAfterResponse(m func(response *Response) error) {
+	c.resty.OnAfterResponse(func(_ *resty.Client, req *resty.Response) error {
+		return m(req)
+	})
+}
+
+// UseURL parses the individual components of the given API URL and configures the client
+// accordingly. For example, a valid URL.
+// For example:
+//
+//	client.UseURL("https://api.test.linode.com/v4beta")
+func (c *Client) UseURL(apiURL string) (*Client, error) {
+	parsedURL, err := url.Parse(apiURL)
+	if err != nil {
+		return nil, fmt.Errorf("failed to parse URL: %w", err)
+	}
+
+	// Create a new URL excluding the path to use as the base URL
+	baseURL := &url.URL{
+		Host:   parsedURL.Host,
+		Scheme: parsedURL.Scheme,
+	}
+
+	c.SetBaseURL(baseURL.String())
+
+	versionMatches := regexp.MustCompile(`/v[a-zA-Z0-9]+`).FindAllString(parsedURL.Path, -1)
+
+	// Only set the version if a version is found in the URL, else use the default
+	if len(versionMatches) > 0 {
+		c.SetAPIVersion(
+			strings.Trim(versionMatches[len(versionMatches)-1], "/"),
+		)
+	}
+
+	return c, nil
+}
+
 // SetBaseURL sets the base URL of the Linode v4 API (https://api.linode.com/v4)
 func (c *Client) SetBaseURL(baseURL string) *Client {
 	baseURLPath, _ := url.Parse(baseURL)
@@ -378,6 +420,16 @@ func (c *Client) SetHeader(name, value string) {
 	c.resty.SetHeader(name, value)
 }
 
+func (c *Client) enableLogSanitization() *Client {
+	c.resty.OnRequestLog(func(r *resty.RequestLog) error {
+		// masking authorization header
+		r.Header.Set("Authorization", "Bearer *******************************")
+		return nil
+	})
+
+	return c
+}
+
 // NewClient factory to create new Client struct
 func NewClient(hc *http.Client) (client Client) {
 	if hc != nil {
@@ -387,7 +439,7 @@ func NewClient(hc *http.Client) (client Client) {
 	}
 
 	client.shouldCache = true
-	client.cacheExpiration = time.Minute * 15
+	client.cacheExpiration = APIDefaultCacheExpiration
 	client.cachedEntries = make(map[string]clientCacheEntry)
 	client.cachedEntryLock = &sync.RWMutex{}
 
@@ -421,10 +473,11 @@ func NewClient(hc *http.Client) (client Client) {
 	}
 
 	client.
-		SetRetryWaitTime((1000 * APISecondsPerPoll) * time.Millisecond).
+		SetRetryWaitTime(APISecondsPerPoll * time.Second).
 		SetPollDelay(APISecondsPerPoll * time.Second).
 		SetRetries().
-		SetDebug(envDebug)
+		SetDebug(envDebug).
+		enableLogSanitization()
 
 	return
 }
@@ -483,7 +536,7 @@ func (c *Client) preLoadConfig(configPath string) error {
 	}
 
 	// We don't want to load the profile until the user is actually making requests
-	c.OnBeforeRequest(func(request *Request) error {
+	c.OnBeforeRequest(func(_ *Request) error {
 		if c.loadedProfile != c.selectedProfile {
 			if err := c.UseProfile(c.selectedProfile); err != nil {
 				return err
