@@ -5,8 +5,8 @@ package linodego
  */
 
 import (
-	"context"
 	"crypto/sha256"
+	"encoding/hex"
 	"encoding/json"
 	"fmt"
 	"reflect"
@@ -53,7 +53,7 @@ func (l ListOptions) Hash() (string, error) {
 
 	h.Write(data)
 
-	return fmt.Sprintf("%x", h.Sum(nil)), nil
+	return hex.EncodeToString(h.Sum(nil)), nil
 }
 
 func applyListOptionsToRequest(opts *ListOptions, req *resty.Request) error {
@@ -90,41 +90,6 @@ type PagedResponse interface {
 	castResult(*resty.Request, string) (int, int, error)
 }
 
-// listHelper abstracts fetching and pagination for GET endpoints that
-// do not require any Ids (top level endpoints).
-// When opts (or opts.Page) is nil, all pages will be fetched and
-// returned in a single (endpoint-specific)PagedResponse
-// opts.results and opts.pages will be updated from the API response
-func (c *Client) listHelper(ctx context.Context, pager PagedResponse, opts *ListOptions, ids ...any) error {
-	req := c.R(ctx)
-	if err := applyListOptionsToRequest(opts, req); err != nil {
-		return err
-	}
-
-	pages, results, err := pager.castResult(req, pager.endpoint(ids...))
-	if err != nil {
-		return err
-	}
-	if opts == nil {
-		opts = &ListOptions{PageOptions: &PageOptions{Page: 0}}
-	}
-	if opts.PageOptions == nil {
-		opts.PageOptions = &PageOptions{Page: 0}
-	}
-	if opts.Page == 0 {
-		for page := 2; page <= pages; page++ {
-			opts.Page = page
-			if err := c.listHelper(ctx, pager, opts, ids...); err != nil {
-				return err
-			}
-		}
-	}
-
-	opts.Results = results
-	opts.Pages = pages
-	return nil
-}
-
 // flattenQueryStruct flattens a structure into a Resty-compatible query param map.
 // Fields are mapped using the `query` struct tag.
 func flattenQueryStruct(val any) (map[string]string, error) {
@@ -196,3 +161,8 @@ func queryFieldToString(value reflect.Value) (string, error) {
 		return "", fmt.Errorf("unsupported query param type: %s", value.Type().Name())
 	}
 }
+
+type legacyPagedResponse[T any] struct {
+	*PageOptions
+	Data []T `json:"data"`
+}
