@@ -6,6 +6,8 @@ import (
 	"strconv"
 	"testing"
 
+	"github.com/stretchr/testify/require"
+
 	"github.com/linode/linodego"
 )
 
@@ -14,7 +16,7 @@ type instanceModifier func(*linodego.Client, *linodego.InstanceCreateOptions)
 func TestInstances_List(t *testing.T) {
 	client, instance, _, teardown, err := setupInstanceWithoutDisks(
 		t,
-		"fixtures/TestInstances_List",
+		"fixtures/TestInstances_List", true,
 		func(client *linodego.Client, options *linodego.InstanceCreateOptions) {
 			options.Region = "eu-west" // Override for metadata availability
 		},
@@ -53,7 +55,7 @@ func TestInstances_List(t *testing.T) {
 }
 
 func TestInstance_Get_smoke(t *testing.T) {
-	client, instance, _, teardown, err := setupInstanceWithoutDisks(t, "fixtures/TestInstance_Get")
+	client, instance, _, teardown, err := setupInstanceWithoutDisks(t, "fixtures/TestInstance_Get", true)
 	defer teardown()
 	if err != nil {
 		t.Error(err)
@@ -82,7 +84,7 @@ func TestInstance_Get_smoke(t *testing.T) {
 func TestInstance_Resize(t *testing.T) {
 	client, instance, teardown, err := setupInstance(
 		t,
-		"fixtures/TestInstance_Resize",
+		"fixtures/TestInstance_Resize", true,
 		func(client *linodego.Client, options *linodego.InstanceCreateOptions) {
 			boot := true
 			options.Type = "g6-nanode-1"
@@ -119,7 +121,7 @@ func TestInstance_Resize(t *testing.T) {
 }
 
 func TestInstance_Disks_List(t *testing.T) {
-	client, instance, teardown, err := setupInstance(t, "fixtures/TestInstance_Disks_List")
+	client, instance, teardown, err := setupInstance(t, "fixtures/TestInstance_Disks_List", true)
 	defer teardown()
 	if err != nil {
 		t.Error(err)
@@ -134,8 +136,33 @@ func TestInstance_Disks_List(t *testing.T) {
 	}
 }
 
+func TestInstance_Disks_List_WithEncryption(t *testing.T) {
+	client, instance, teardown, err := setupInstance(t, "fixtures/TestInstance_Disks_List_WithEncryption", true, func(c *linodego.Client, ico *linodego.InstanceCreateOptions) {
+		ico.Region = getRegionsWithCaps(t, c, []string{"Disk Encryption"})[0]
+	})
+	defer teardown()
+	if err != nil {
+		t.Error(err)
+	}
+
+	disks, err := client.ListInstanceDisks(context.Background(), instance.ID, nil)
+	if err != nil {
+		t.Errorf("Error listing instance disks, expected struct, got error %v", err)
+	}
+	if len(disks) == 0 {
+		t.Errorf("Expected a list of instance disks, but got %v", disks)
+	}
+
+	// Disk Encryption should be enabled by default if not otherwise specified
+	for _, disk := range disks {
+		if disk.DiskEncryption != linodego.InstanceDiskEncryptionEnabled {
+			t.Fatalf("expected disk encryption status: %s, got :%s", linodego.InstanceDiskEncryptionEnabled, disk.DiskEncryption)
+		}
+	}
+}
+
 func TestInstance_Disk_Resize(t *testing.T) {
-	client, instance, _, teardown, err := setupInstanceWithoutDisks(t, "fixtures/TestInstance_Disk_Resize")
+	client, instance, _, teardown, err := setupInstanceWithoutDisks(t, "fixtures/TestInstance_Disk_Resize", true)
 	defer teardown()
 	if err != nil {
 		t.Error(err)
@@ -168,7 +195,7 @@ func TestInstance_Disk_Resize(t *testing.T) {
 
 func TestInstance_Disk_ListMultiple(t *testing.T) {
 	// This is a long running test
-	client, instance1, teardown1, err := setupInstance(t, "fixtures/TestInstance_Disk_ListMultiple_Primary")
+	client, instance1, teardown1, err := setupInstance(t, "fixtures/TestInstance_Disk_ListMultiple_Primary", true)
 	defer teardown1()
 	if err != nil {
 		t.Error(err)
@@ -201,7 +228,7 @@ func TestInstance_Disk_ListMultiple(t *testing.T) {
 		t.Error(err)
 	}
 
-	client, instance2, _, teardown2, err := setupInstanceWithoutDisks(t, "fixtures/TestInstance_Disk_ListMultiple_Secondary")
+	client, instance2, _, teardown2, err := setupInstanceWithoutDisks(t, "fixtures/TestInstance_Disk_ListMultiple_Secondary", true)
 	defer teardown2()
 	if err != nil {
 		t.Error(err)
@@ -244,7 +271,7 @@ func TestInstance_Disk_ListMultiple(t *testing.T) {
 }
 
 func TestInstance_Disk_ResetPassword(t *testing.T) {
-	client, instance, _, teardown, err := setupInstanceWithoutDisks(t, "fixtures/TestInstance_Disk_ResetPassword")
+	client, instance, _, teardown, err := setupInstanceWithoutDisks(t, "fixtures/TestInstance_Disk_ResetPassword", true)
 	defer teardown()
 	if err != nil {
 		t.Error(err)
@@ -282,20 +309,26 @@ func TestInstance_Disk_ResetPassword(t *testing.T) {
 }
 
 func TestInstance_Volumes_List(t *testing.T) {
-	client, instance, config, teardown, err := setupInstanceWithoutDisks(t, "fixtures/TestInstance_Volumes_List_Instance")
+	client, instance, config, teardown, err := setupInstanceWithoutDisks(t, "fixtures/TestInstance_Volumes_List_Instance", true)
 	defer teardown()
 	if err != nil {
 		t.Error(err)
 	}
 
-	clientVol, volume, teardown, err := setupVolume(t, "fixtures/TestInstance_Volumes_List")
-	defer teardown()
+	volume, teardown, volErr := createVolume(t, client)
+
+	_, err = client.WaitForVolumeStatus(context.Background(), volume.ID, linodego.VolumeActive, 500)
 	if err != nil {
+		t.Errorf("Error waiting for volume to be active, %s", err)
+	}
+
+	defer teardown()
+	if volErr != nil {
 		t.Error(err)
 	}
 
 	configOpts := linodego.InstanceConfigUpdateOptions{
-		Label: "go-vol-test" + randLabel(),
+		Label: "go-vol-test" + getUniqueText(),
 		Devices: &linodego.InstanceConfigDeviceMap{
 			SDA: &linodego.InstanceConfigDevice{
 				VolumeID: volume.ID,
@@ -307,7 +340,7 @@ func TestInstance_Volumes_List(t *testing.T) {
 		t.Error(err)
 	}
 
-	volumes, err := clientVol.ListInstanceVolumes(context.Background(), instance.ID, nil)
+	volumes, err := client.ListInstanceVolumes(context.Background(), instance.ID, nil)
 	if err != nil {
 		t.Errorf("Error listing instance volumes, expected struct, got error %v", err)
 	}
@@ -329,7 +362,7 @@ func TestInstance_CreateUnderFirewall(t *testing.T) {
 	}
 	_, _, teardownInstance, err := createInstanceWithoutDisks(
 		t,
-		client,
+		client, true,
 		func(_ *linodego.Client, options *linodego.InstanceCreateOptions) {
 			options.FirewallID = firewall.ID
 		},
@@ -344,7 +377,7 @@ func TestInstance_CreateUnderFirewall(t *testing.T) {
 func TestInstance_Rebuild(t *testing.T) {
 	client, instance, _, teardown, err := setupInstanceWithoutDisks(
 		t,
-		"fixtures/TestInstance_Rebuild",
+		"fixtures/TestInstance_Rebuild", true,
 		func(client *linodego.Client, options *linodego.InstanceCreateOptions) {
 			options.Region = getRegionsWithCaps(t, client, []string{"Metadata"})[0]
 		},
@@ -361,7 +394,7 @@ func TestInstance_Rebuild(t *testing.T) {
 	}
 
 	rebuildOpts := linodego.InstanceRebuildOptions{
-		Image: "linode/alpine3.15",
+		Image: "linode/alpine3.19",
 		Metadata: &linodego.InstanceMetadataOptions{
 			UserData: base64.StdEncoding.EncodeToString([]byte("cool")),
 		},
@@ -378,11 +411,48 @@ func TestInstance_Rebuild(t *testing.T) {
 	}
 }
 
+func TestInstance_RebuildWithEncryption(t *testing.T) {
+	client, instance, _, teardown, err := setupInstanceWithoutDisks(
+		t,
+		"fixtures/TestInstance_RebuildWithEncryption",
+		true,
+		func(client *linodego.Client, options *linodego.InstanceCreateOptions) {
+			options.Region = getRegionsWithCaps(t, client, []string{"Disk Encryption"})[0]
+			options.DiskEncryption = linodego.InstanceDiskEncryptionEnabled
+		},
+	)
+	defer teardown()
+
+	if err != nil {
+		t.Error(err)
+	}
+
+	_, err = client.WaitForEventFinished(context.Background(), instance.ID, linodego.EntityLinode, linodego.ActionLinodeCreate, *instance.Created, 180)
+	if err != nil {
+		t.Errorf("Error waiting for instance created: %s", err)
+	}
+
+	rebuildOpts := linodego.InstanceRebuildOptions{
+		Image:          "linode/alpine3.19",
+		RootPass:       randPassword(),
+		Type:           "g6-standard-2",
+		DiskEncryption: linodego.InstanceDiskEncryptionDisabled,
+	}
+	instance, err = client.RebuildInstance(context.Background(), instance.ID, rebuildOpts)
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	if instance.DiskEncryption != linodego.InstanceDiskEncryptionDisabled {
+		t.Fatalf("expected instance.DiskEncryption to be: %s, got: %s", linodego.InstanceDiskEncryptionDisabled, linodego.InstanceDiskEncryptionEnabled)
+	}
+}
+
 func TestInstance_Clone(t *testing.T) {
 	var targetRegion string
 
 	client, instance, teardownOriginalLinode, err := setupInstance(
-		t, "fixtures/TestInstance_Clone",
+		t, "fixtures/TestInstance_Clone", true,
 		func(client *linodego.Client, options *linodego.InstanceCreateOptions) {
 			targetRegion = getRegionsWithCaps(t, client, []string{"Metadata"})[0]
 
@@ -457,7 +527,7 @@ func TestInstance_Clone(t *testing.T) {
 }
 
 func TestInstance_withMetadata(t *testing.T) {
-	_, inst, _, teardown, err := setupInstanceWithoutDisks(t, "fixtures/TestInstance_withMetadata",
+	_, inst, _, teardown, err := setupInstanceWithoutDisks(t, "fixtures/TestInstance_withMetadata", true,
 		func(client *linodego.Client, options *linodego.InstanceCreateOptions) {
 			options.Metadata = &linodego.InstanceMetadataOptions{
 				UserData: base64.StdEncoding.EncodeToString([]byte("reallycoolmetadata")),
@@ -475,19 +545,66 @@ func TestInstance_withMetadata(t *testing.T) {
 	}
 }
 
-func createInstance(t *testing.T, client *linodego.Client, modifiers ...instanceModifier) (*linodego.Instance, error) {
+func TestInstance_DiskEncryption(t *testing.T) {
+	_, inst, teardown, err := setupInstance(t, "fixtures/TestInstance_DiskEncryption", true, func(c *linodego.Client, ico *linodego.InstanceCreateOptions) {
+		ico.DiskEncryption = linodego.InstanceDiskEncryptionEnabled
+		ico.Region = "us-east"
+	})
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	t.Cleanup(teardown)
+
+	if inst.DiskEncryption != linodego.InstanceDiskEncryptionEnabled {
+		t.Fatalf("expected instance to have disk encryption enabled, got: %s, want: %s", inst.DiskEncryption, linodego.InstanceDiskEncryptionEnabled)
+	}
+}
+
+func TestInstance_withPG(t *testing.T) {
+	client, clientTeardown := createTestClient(t, "fixtures/TestInstance_withPG")
+
+	pg, pgTeardown, err := createPlacementGroup(t, client)
+	require.NoError(t, err)
+
+	// Create an instance to assign to the PG
+	inst, err := createInstance(t, client, true, func(client *linodego.Client, options *linodego.InstanceCreateOptions) {
+		options.Region = pg.Region
+		options.PlacementGroup = &linodego.InstanceCreatePlacementGroupOptions{
+			ID: pg.ID,
+		}
+	})
+	require.NoError(t, err)
+
+	defer func() {
+		client.DeleteInstance(context.Background(), inst.ID)
+		pgTeardown()
+		clientTeardown()
+	}()
+
+	require.NotNil(t, inst.PlacementGroup)
+	require.Equal(t, inst.PlacementGroup.ID, pg.ID)
+	require.Equal(t, inst.PlacementGroup.Label, pg.Label)
+	require.Equal(t, inst.PlacementGroup.PlacementGroupType, pg.PlacementGroupType)
+	require.Equal(t, inst.PlacementGroup.PlacementGroupPolicy, pg.PlacementGroupPolicy)
+}
+
+func createInstance(t *testing.T, client *linodego.Client, enableCloudFirewall bool, modifiers ...instanceModifier) (*linodego.Instance, error) {
 	if t != nil {
 		t.Helper()
 	}
 
-	booted := false
 	createOpts := linodego.InstanceCreateOptions{
 		Label:    "go-test-ins-" + randLabel(),
 		RootPass: randPassword(),
 		Region:   getRegionsWithCaps(t, client, []string{"linodes"})[0],
 		Type:     "g6-nanode-1",
 		Image:    "linode/debian9",
-		Booted:   &booted,
+		Booted:   linodego.Pointer(false),
+	}
+
+	if enableCloudFirewall {
+		createOpts.FirewallID = firewallID
 	}
 
 	for _, modifier := range modifiers {
@@ -496,13 +613,13 @@ func createInstance(t *testing.T, client *linodego.Client, modifiers ...instance
 	return client.CreateInstance(context.Background(), createOpts)
 }
 
-func setupInstance(t *testing.T, fixturesYaml string, modifiers ...instanceModifier) (*linodego.Client, *linodego.Instance, func(), error) {
+func setupInstance(t *testing.T, fixturesYaml string, EnableCloudFirewall bool, modifiers ...instanceModifier) (*linodego.Client, *linodego.Instance, func(), error) {
 	if t != nil {
 		t.Helper()
 	}
 	client, fixtureTeardown := createTestClient(t, fixturesYaml)
 
-	instance, err := createInstance(t, client, modifiers...)
+	instance, err := createInstance(t, client, EnableCloudFirewall, modifiers...)
 	if err != nil {
 		t.Errorf("failed to create test instance: %s", err)
 	}
@@ -521,16 +638,20 @@ func setupInstance(t *testing.T, fixturesYaml string, modifiers ...instanceModif
 func createInstanceWithoutDisks(
 	t *testing.T,
 	client *linodego.Client,
+	enableCloudFirewall bool,
 	modifiers ...instanceModifier,
 ) (*linodego.Instance, *linodego.InstanceConfig, func(), error) {
 	t.Helper()
 
-	falseBool := false
 	createOpts := linodego.InstanceCreateOptions{
 		Label:  "go-test-ins-wo-disk-" + randLabel(),
 		Region: getRegionsWithCaps(t, client, []string{"linodes"})[0],
 		Type:   "g6-nanode-1",
-		Booted: &falseBool,
+		Booted: linodego.Pointer(false),
+	}
+
+	if enableCloudFirewall {
+		createOpts.FirewallID = GetFirewallID()
 	}
 
 	for _, modifier := range modifiers {
@@ -559,10 +680,10 @@ func createInstanceWithoutDisks(
 	return instance, config, teardown, err
 }
 
-func setupInstanceWithoutDisks(t *testing.T, fixturesYaml string, modifiers ...instanceModifier) (*linodego.Client, *linodego.Instance, *linodego.InstanceConfig, func(), error) {
+func setupInstanceWithoutDisks(t *testing.T, fixturesYaml string, enableCloudFirewall bool, modifiers ...instanceModifier) (*linodego.Client, *linodego.Instance, *linodego.InstanceConfig, func(), error) {
 	t.Helper()
 	client, fixtureTeardown := createTestClient(t, fixturesYaml)
-	instance, config, instanceTeardown, err := createInstanceWithoutDisks(t, client, modifiers...)
+	instance, config, instanceTeardown, err := createInstanceWithoutDisks(t, client, enableCloudFirewall, modifiers...)
 
 	teardown := func() {
 		instanceTeardown()
